summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/com/android/camera/ui/AutoFitSurfaceView.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/com/android/camera/ui/AutoFitSurfaceView.java b/src/com/android/camera/ui/AutoFitSurfaceView.java
index f4903e19f..38be39cf9 100644
--- a/src/com/android/camera/ui/AutoFitSurfaceView.java
+++ b/src/com/android/camera/ui/AutoFitSurfaceView.java
@@ -14,29 +14,29 @@
* limitations under the License.
*/
-package com.example.android.camera2basic;
+package com.android.camera.ui;
import android.content.Context;
import android.util.AttributeSet;
-import android.view.TextureView;
+import android.view.SurfaceView;
/**
* A {@link TextureView} that can be adjusted to a specified aspect ratio.
*/
-public class AutoFitTextureView extends TextureView {
+public class AutoFitSurfaceView extends SurfaceView {
private int mRatioWidth = 0;
private int mRatioHeight = 0;
- public AutoFitTextureView(Context context) {
+ public AutoFitSurfaceView(Context context) {
this(context, null);
}
- public AutoFitTextureView(Context context, AttributeSet attrs) {
+ public AutoFitSurfaceView(Context context, AttributeSet attrs) {
this(context, attrs, 0);
}
- public AutoFitTextureView(Context context, AttributeSet attrs, int defStyle) {
+ public AutoFitSurfaceView(Context context, AttributeSet attrs, int defStyle) {
super(context, attrs, defStyle);
}
@@ -14,29 +14,29 @@
/**
- * A {@link TextureView} that can be adjusted to a specified aspect ratio.
+ * A {@link SurfaceView} that can be adjusted to a specified aspect ratio.
*/